@@ -467,7 +467,7 @@ namespace mgnat.adalib
          }
       }
 
-      //  Special method to allow the top level file I/O pacakges
+      //  Special method to allow the top level file I/O packages
       //  to communicate the class of file API to be used by fopen
       //  (e.g., RandomAccessFile, Object_File). This avoids making
       //  JGNAT-specific changes to the lower-level file support
@@ -528,8 +528,13 @@ namespace mgnat.adalib
                }
 
                //  In read_update, we need to open a StreamWriter, setting
-               //  the mode to Append to allow update
+               //  the mode to Append to allow update. No action needed if
+               //  the file does not exist.
+
                else if (read_update) {
+                  if (__gnat_file_exists (filename) == 0) {
+                     return null;
+                  }
                   StreamWriter s = new StreamWriter
                     (File.Open (to_string (filename), FileMode.Append));
                   return s;
